.. currentmodule:: abjad.tools.selectortools

select_all_but_last_logical_tie_in_pitched_runs
===============================================

.. autofunction:: select_all_but_last_logical_tie_in_pitched_runs
